# -*- coding: utf-8 -*-

from django.contrib import admin
from django.utils.translation import get_language
from django.utils.translation import ugettext_lazy as _

from jmb.core.admin.options import ExtendibleModelAdmin

from thux.l10n.models import Country, AdministrativeArea


class AdministrativeAreaInline(admin.TabularInline):
    model = AdministrativeArea
    extra = 1


class CountryAdmin(ExtendibleModelAdmin):
    list_display = ('printable_name', 'iso2_code', 'iso3_code', 'get_edit_icon', 'get_delete_icon',)
    list_display_links = ('get_edit_icon',)
    # list_filter = ('continent', 'active')
    fieldsets = (
        (None, {
            'fields': ('active',)
        }),
        (_("denomination"), {
            'fields': ('printable_name', 'name'),
        }),
        (_("codes"), {
            'fields': ('iso2_code', 'iso3_code', 'numcode',)
        }),
        (None, {
            'fields': ('continent', 'admin_area',),
        }),
    )
    search_fields = ('name', 'iso2_code', 'iso3_code',)
    inlines = [AdministrativeAreaInline]


admin.site.register(Country, CountryAdmin)
