# -*- coding: utf-8 -*-

import datetime

from django.db import connections
from django.db.models import Sum
from django.utils.translation import ugettext_lazy as _

import admin_tools
from admin_tools.dashboard import modules, register, AppIndexDashboard

from jmb.core.admin import dashboard as jmb_dashboard

from thux.l10n.models import Country


class DefaultDashboard(modules.Group):
    def __init__(self, **kwargs):

        today = datetime.date.today()
        kwargs.update({
            'title': _("l10n"),
            'display': "tabs",
            'children': [
                # CustomModule(
                #     title='Today L10n',
                #     order_by='-date_create',
                #     limit=None,
                #     extra_filters={'date_create__gte': today},
                # ),
                Models(),
#                OtherModels(),
#                L10nSettings(),
#                Permissions(),
            ]
        })
        super(DefaultDashboard, self).__init__(**kwargs)


class L10nDashboard(modules.Group):
    def __init__(self, **kwargs):

        today = datetime.date.today()
        kwargs.update({
            'title': _("l10n"),
            'display': "tabs",
            'children': [
                Models(),
#                OtherModels(),
#                Settings(),
#                Permissions(),
            ]
        })
        super(L10nDashboard, self).__init__(**kwargs)


class Models(modules.ModelList):
    def __init__(self, **kwargs):
        kwargs.update({
            'title': _("main models"),
            'models': ('thux.l10n.models.*',),
        })
        super(Models, self).__init__(**kwargs)


class OtherModels(modules.ModelList):
    def __init__(self, **kwargs):
        kwargs.update({
            'title': _("others"),
            'models': (),
        })
        super(OtherModels, self).__init__(**kwargs)

# class Settings(modules.ModelList):
#     def __init__(self, **kwargs):
#         kwargs.update({
#             'title': _("settings"),
#             'models':['thux.l10n.models.Settings',],
#             })
#         super(Settings, self).__init__(**kwargs)


# class Permissions(modules.ModelList):
#     def __init__(self, **kwargs):
#         kwargs.update({
#             'title': _("permissions"),
#             'models': ['thux.l10n.models.L10nPermissions',],
#         })
#         super(Permissions, self).__init__(**kwargs)


# class CustomModule(modules.DashboardModule):
#     """Esempio di modulo che produce contentuto generico
#     """
#     def __init__(self, title, template='admin_tools/l10n/custom.html',
#                  order_by=None, limit=10, qs=L10n.objects.all(), extra_filters={},
#                  children=None, **kwargs):
#         self.order_by = order_by
#         self.template = template
#         self.qs = qs
#         self.extra_filters = extra_filters
#         self.limit = limit
#         self.custom_children = children
#
#         kwargs.update({
#             'title': title,
#             'template': self.template,
#             'children': self.custom_children
#         })
#         super(CustomModule, self).__init__(**kwargs)
#
#     def init_with_context(self, context):
#         request = context['request']
#         if self.custom_children is None:
#             qs = self.qs
#             if self.extra_filters:
#                 qs = qs.filter(**self.extra_filters)
#             if self.order_by:
#                 qs = qs.order_by(self.order_by)
#             if self.limit:
#                 qs = qs[:self.limit]
#             self.children = qs


class DefaultAppDashboard(AppIndexDashboard):
    def __init__(self, app_title, models, **kwargs):
        AppIndexDashboard.__init__(self, app_title, models, **kwargs)
        self.columns = 3

    def init_with_context(self, context):
        self.children.append(
            DefaultDashboard(),
        )

# Used in /admin
jmb_dashboard.register_group(L10nDashboard, 'thux.l10n')
# Used in /admin/L10n
admin_tools.dashboard.register(DefaultAppDashboard, 'thux.l10n')
